==> apache-camel-3.3.0-src.zip: apache-camel-3.3.0/components/camel-netty-http/src/test/java/org/apache/camel/component/netty/http/NettyHttpReturnDataNotInputStreamConvertableTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.netty.http;

import org.apache.camel.builder.RouteBuilder;
import org.junit.Test;

public class NettyHttpReturnDataNotInputStreamConvertableTest extends BaseNettyTest {

    @Test
    public void testHttpReturnDataNotInputStreamConvertableTest() throws Exception {
        String out = template.requestBody("netty-http:http://localhost:{{port}}/test", "Hello World", String.class);
        assertEquals("This is the response", out);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("netty-http:http://localhost:{{port}}/test")
                        .process(exchange -> exchange.getMessage().setBody(new MyResponseBean()));
            }
        };
    }

    private static class MyResponseBean {
        @Override
        public String toString() {
            return "This is the response";
        }
    }
}

==> apache-camel-3.7.6-src.zip: apache-camel-3.7.6/components/camel-netty-http/src/test/java/org/apache/camel/component/netty/http/NettyHttpReturnDataNotInputStreamConvertableTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.netty.http;

import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class NettyHttpReturnDataNotInputStreamConvertableTest extends BaseNettyTest {

    @Test
    public void testHttpReturnDataNotInputStreamConvertableTest() throws Exception {
        String out = template.requestBody("netty-http:http://localhost:{{port}}/test", "Hello World", String.class);
        assertEquals("This is the response", out);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("netty-http:http://localhost:{{port}}/test")
                        .process(exchange -> exchange.getMessage().setBody(new MyResponseBean()));
            }
        };
    }

    private static class MyResponseBean {
        @Override
        public String toString() {
            return "This is the response";
        }
    }
}
